@@ -59,7 +59,7 @@ class Minecraft:
                 zipf.extract(i, f'{self.path}\\{self.name}-natives\\')
 
 
-    def launch(self,size=[854,480],memorym=128,memoryx=1024,username='test',java=r'java',launcher=['unknow_launcher','001'],is_ent=False):
+    def launch(self,uuid='${uuid}',access_token='${access_token}',size=[854,480],memorym=128,memoryx=1024,username='test',java=r'java',launcher=['unknow_launcher','001'],is_ent=False):
         lib = f'{self.path}\\{self.name}-natives\\'
         lib_path = self.path.replace(self.name,'').replace('\\versions','')+'libraries'
         new_lib = []
@@ -76,9 +76,16 @@ class Minecraft:
 
         cp = '-cp "'
         for i in new_lib:
-            cp += i + ';'
+            if i.split('\\')[-2] == '3.2.1':
+                pass
+            else:
+                cp += i + ';'
+
+
         jar_file = f'{self.path}\\{self.name}.jar'
-        print(jar_file)
+
+
+
 
         cp += f'{jar_file}"'
 
@@ -93,12 +100,17 @@ class Minecraft:
             arguments = arguments.replace('${game_directory}', f'"{self.path.replace(dw,"")}"')
         dw = '\\versions\\' + self.name
         arguments = arguments.replace('${assets_root}',f'"{self.path.replace(dw,"")}\\assets"')
-
+        arguments = arguments.replace('${game_assets}', f'"{self.path.replace(dw,"")}\\assets"')
         try:
 
             arguments = arguments.replace('${assets_index_name}',self.json_dict['assets'])
+
+
+
         except BaseException as e:
             print(e)
+        arguments = arguments.replace('${auth_uuid}',uuid)
+        arguments = arguments.replace('${auth_access_token}',access_token)
         arguments = arguments.replace('${user_type}','Mojang')
         arguments = arguments.replace('${resolution_width}', str(size[0]))
         arguments = arguments.replace('${resolution_height}', str(size[1]))
@@ -110,6 +122,7 @@ class Minecraft:
 
         dw = '\\versions\\' + self.name
         print(command)
+        os.chdir(self.path)
         os.system(command)
 
 
